# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/abci/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.crypto import proof_pb2 as tendermint_dot_crypto_dot_proof__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
from tendermint.types import params_pb2 as tendermint_dot_types_dot_params__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1btendermint/abci/types.proto\x12\x0ftendermint.abci\x1a\x1dtendermint/crypto/proof.proto\x1a\x1ctendermint/types/types.proto\x1a\x1ctendermint/crypto/keys.proto\x1a\x1dtendermint/types/params.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"\xea\x06\n\x07Request\x12,\n\x04\x65\x63ho\x18\x01 \x01(\x0b\x32\x1c.tendermint.abci.RequestEchoH\x00\x12.\n\x05\x66lush\x18\x02 \x01(\x0b\x32\x1d.tendermint.abci.RequestFlushH\x00\x12,\n\x04info\x18\x03 \x01(\x0b\x32\x1c.tendermint.abci.RequestInfoH\x00\x12\x37\n\nset_option\x18\x04 \x01(\x0b\x32!.tendermint.abci.RequestSetOptionH\x00\x12\x37\n\ninit_chain\x18\x05 \x01(\x0b\x32!.tendermint.abci.RequestInitChainH\x00\x12.\n\x05query\x18\x06 \x01(\x0b\x32\x1d.tendermint.abci.RequestQueryH\x00\x12\x39\n\x0b\x62\x65gin_block\x18\x07 \x01(\x0b\x32\".tendermint.abci.RequestBeginBlockH\x00\x12\x33\n\x08\x63heck_tx\x18\x08 \x01(\x0b\x32\x1f.tendermint.abci.RequestCheckTxH\x00\x12\x37\n\ndeliver_tx\x18\t \x01(\x0b\x32!.tendermint.abci.RequestDeliverTxH\x00\x12\x35\n\tend_block\x18\n \x01(\x0b\x32 .tendermint.abci.RequestEndBlockH\x00\x12\x30\n\x06\x63ommit\x18\x0b \x01(\x0b\x32\x1e.tendermint.abci.RequestCommitH\x00\x12?\n\x0elist_snapshots\x18\x0c \x01(\x0b\x32%.tendermint.abci.RequestListSnapshotsH\x00\x12?\n\x0eoffer_snapshot\x18\r \x01(\x0b\x32%.tendermint.abci.RequestOfferSnapshotH\x00\x12H\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b\x32).tendermint.abci.RequestLoadSnapshotChunkH\x00\x12J\n\x14\x61pply_snapshot_chunk\x18\x0f \x01(\x0b\x32*.tendermint.abci.RequestApplySnapshotChunkH\x00\x42\x07\n\x05value\"\x1e\n\x0bRequestEcho\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0e\n\x0cRequestFlush\"J\n\x0bRequestInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rblock_version\x18\x02 \x01(\x04\x12\x13\n\x0bp2p_version\x18\x03 \x01(\x04\".\n\x10RequestSetOption\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x81\x02\n\x10RequestInitChain\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\x12:\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32 .tendermint.abci.ConsensusParams\x12:\n\nvalidators\x18\x04 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x17\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0c\x12\x16\n\x0einitial_height\x18\x06 \x01(\x03\"I\n\x0cRequestQuery\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\r\n\x05prove\x18\x04 \x01(\x08\"\xd1\x01\n\x11RequestBeginBlock\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12.\n\x06header\x18\x02 \x01(\x0b\x32\x18.tendermint.types.HeaderB\x04\xc8\xde\x1f\x00\x12?\n\x10last_commit_info\x18\x03 \x01(\x0b\x32\x1f.tendermint.abci.LastCommitInfoB\x04\xc8\xde\x1f\x00\x12=\n\x14\x62yzantine_validators\x18\x04 \x03(\x0b\x32\x19.tendermint.abci.EvidenceB\x04\xc8\xde\x1f\x00\"H\n\x0eRequestCheckTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.tendermint.abci.CheckTxType\"\x1e\n\x10RequestDeliverTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\"!\n\x0fRequestEndBlock\x12\x0e\n\x06height\x18\x01 \x01(\x03\"\x0f\n\rRequestCommit\"\x16\n\x14RequestListSnapshots\"U\n\x14RequestOfferSnapshot\x12+\n\x08snapshot\x18\x01 \x01(\x0b\x32\x19.tendermint.abci.Snapshot\x12\x10\n\x08\x61pp_hash\x18\x02 \x01(\x0c\"I\n\x18RequestLoadSnapshotChunk\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\r\n\x05\x63hunk\x18\x03 \x01(\r\"I\n\x19RequestApplySnapshotChunk\x12\r\n\x05index\x18\x01 \x01(\r\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\x12\x0e\n\x06sender\x18\x03 \x01(\t\"\xb3\x07\n\x08Response\x12\x37\n\texception\x18\x01 \x01(\x0b\x32\".tendermint.abci.ResponseExceptionH\x00\x12-\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x1d.tendermint.abci.ResponseEchoH\x00\x12/\n\x05\x66lush\x18\x03 \x01(\x0b\x32\x1e.tendermint.abci.ResponseFlushH\x00\x12-\n\x04info\x18\x04 \x01(\x0b\x32\x1d.tendermint.abci.ResponseInfoH\x00\x12\x38\n\nset_option\x18\x05 \x01(\x0b\x32\".tendermint.abci.ResponseSetOptionH\x00\x12\x38\n\ninit_chain\x18\x06 \x01(\x0b\x32\".tendermint.abci.ResponseInitChainH\x00\x12/\n\x05query\x18\x07 \x01(\x0b\x32\x1e.tendermint.abci.ResponseQueryH\x00\x12:\n\x0b\x62\x65gin_block\x18\x08 \x01(\x0b\x32#.tendermint.abci.ResponseBeginBlockH\x00\x12\x34\n\x08\x63heck_tx\x18\t \x01(\x0b\x32 .tendermint.abci.ResponseCheckTxH\x00\x12\x38\n\ndeliver_tx\x18\n \x01(\x0b\x32\".tendermint.abci.ResponseDeliverTxH\x00\x12\x36\n\tend_block\x18\x0b \x01(\x0b\x32!.tendermint.abci.ResponseEndBlockH\x00\x12\x31\n\x06\x63ommit\x18\x0c \x01(\x0b\x32\x1f.tendermint.abci.ResponseCommitH\x00\x12@\n\x0elist_snapshots\x18\r \x01(\x0b\x32&.tendermint.abci.ResponseListSnapshotsH\x00\x12@\n\x0eoffer_snapshot\x18\x0e \x01(\x0b\x32&.tendermint.abci.ResponseOfferSnapshotH\x00\x12I\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b\x32*.tendermint.abci.ResponseLoadSnapshotChunkH\x00\x12K\n\x14\x61pply_snapshot_chunk\x18\x10 \x01(\x0b\x32+.tendermint.abci.ResponseApplySnapshotChunkH\x00\x42\x07\n\x05value\"\"\n\x11ResponseException\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\x1f\n\x0cResponseEcho\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0f\n\rResponseFlush\"z\n\x0cResponseInfo\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\x04\x12\x19\n\x11last_block_height\x18\x04 \x01(\x03\x12\x1b\n\x13last_block_app_hash\x18\x05 \x01(\x0c\"<\n\x11ResponseSetOption\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\"\x9d\x01\n\x11ResponseInitChain\x12:\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32 .tendermint.abci.ConsensusParams\x12:\n\nvalidators\x18\x02 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x10\n\x08\x61pp_hash\x18\x03 \x01(\x0c\"\xb6\x01\n\rResponseQuery\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x03\x12\x0b\n\x03key\x18\x06 \x01(\x0c\x12\r\n\x05value\x18\x07 \x01(\x0c\x12.\n\tproof_ops\x18\x08 \x01(\x0b\x32\x1b.tendermint.crypto.ProofOps\x12\x0e\n\x06height\x18\t \x01(\x03\x12\x11\n\tcodespace\x18\n \x01(\t\"V\n\x12ResponseBeginBlock\x12@\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\"\xd9\x01\n\x0fResponseCheckTx\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12@\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t\"\xdb\x01\n\x11ResponseDeliverTx\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12@\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t\"\xda\x01\n\x10ResponseEndBlock\x12\x41\n\x11validator_updates\x18\x01 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x41\n\x17\x63onsensus_param_updates\x18\x02 \x01(\x0b\x32 .tendermint.abci.ConsensusParams\x12@\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\"5\n\x0eResponseCommit\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x15\n\rretain_height\x18\x03 \x01(\x03\"E\n\x15ResponseListSnapshots\x12,\n\tsnapshots\x18\x01 \x03(\x0b\x32\x19.tendermint.abci.Snapshot\"\xb6\x01\n\x15ResponseOfferSnapshot\x12=\n\x06result\x18\x01 \x01(\x0e\x32-.tendermint.abci.ResponseOfferSnapshot.Result\"^\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\t\n\x05\x41\x42ORT\x10\x02\x12\n\n\x06REJECT\x10\x03\x12\x11\n\rREJECT_FORMAT\x10\x04\x12\x11\n\rREJECT_SENDER\x10\x05\"*\n\x19ResponseLoadSnapshotChunk\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\"\xf2\x01\n\x1aResponseApplySnapshotChunk\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32\x32.tendermint.abci.ResponseApplySnapshotChunk.Result\x12\x16\n\x0erefetch_chunks\x18\x02 \x03(\r\x12\x16\n\x0ereject_senders\x18\x03 \x03(\t\"`\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\t\n\x05\x41\x42ORT\x10\x02\x12\t\n\x05RETRY\x10\x03\x12\x12\n\x0eRETRY_SNAPSHOT\x10\x04\x12\x13\n\x0fREJECT_SNAPSHOT\x10\x05\"\xda\x01\n\x0f\x43onsensusParams\x12+\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1c.tendermint.abci.BlockParams\x12\x32\n\x08\x65vidence\x18\x02 \x01(\x0b\x32 .tendermint.types.EvidenceParams\x12\x34\n\tvalidator\x18\x03 \x01(\x0b\x32!.tendermint.types.ValidatorParams\x12\x30\n\x07version\x18\x04 \x01(\x0b\x32\x1f.tendermint.types.VersionParams\"1\n\x0b\x42lockParams\x12\x11\n\tmax_bytes\x18\x01 \x01(\x03\x12\x0f\n\x07max_gas\x18\x02 \x01(\x03\"O\n\x0eLastCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12.\n\x05votes\x18\x02 \x03(\x0b\x32\x19.tendermint.abci.VoteInfoB\x04\xc8\xde\x1f\x00\"h\n\x05\x45vent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12Q\n\nattributes\x18\x02 \x03(\x0b\x32\x1f.tendermint.abci.EventAttributeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x14\x61ttributes,omitempty\";\n\x0e\x45ventAttribute\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\r\n\x05index\x18\x03 \x01(\x08\"o\n\x08TxResult\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05index\x18\x02 \x01(\r\x12\n\n\x02tx\x18\x03 \x01(\x0c\x12\x38\n\x06result\x18\x04 \x01(\x0b\x32\".tendermint.abci.ResponseDeliverTxB\x04\xc8\xde\x1f\x00\"+\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\r\n\x05power\x18\x03 \x01(\x03\"U\n\x0fValidatorUpdate\x12\x33\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\r\n\x05power\x18\x02 \x01(\x03\"Z\n\x08VoteInfo\x12\x33\n\tvalidator\x18\x01 \x01(\x0b\x32\x1a.tendermint.abci.ValidatorB\x04\xc8\xde\x1f\x00\x12\x19\n\x11signed_last_block\x18\x02 \x01(\x08\"\xcc\x01\n\x08\x45vidence\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.tendermint.abci.EvidenceType\x12\x33\n\tvalidator\x18\x02 \x01(\x0b\x32\x1a.tendermint.abci.ValidatorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x32\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1a\n\x12total_voting_power\x18\x05 \x01(\x03\"Z\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\x0e\n\x06\x63hunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x10\n\x08metadata\x18\x05 \x01(\x0c*9\n\x0b\x43heckTxType\x12\x10\n\x03NEW\x10\x00\x1a\x07\x8a\x9d \x03New\x12\x18\n\x07RECHECK\x10\x01\x1a\x0b\x8a\x9d \x07Recheck*H\n\x0c\x45videnceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x44UPLICATE_VOTE\x10\x01\x12\x17\n\x13LIGHT_CLIENT_ATTACK\x10\x02\x32\x83\n\n\x0f\x41\x42\x43IApplication\x12\x43\n\x04\x45\x63ho\x12\x1c.tendermint.abci.RequestEcho\x1a\x1d.tendermint.abci.ResponseEcho\x12\x46\n\x05\x46lush\x12\x1d.tendermint.abci.RequestFlush\x1a\x1e.tendermint.abci.ResponseFlush\x12\x43\n\x04Info\x12\x1c.tendermint.abci.RequestInfo\x1a\x1d.tendermint.abci.ResponseInfo\x12R\n\tSetOption\x12!.tendermint.abci.RequestSetOption\x1a\".tendermint.abci.ResponseSetOption\x12R\n\tDeliverTx\x12!.tendermint.abci.RequestDeliverTx\x1a\".tendermint.abci.ResponseDeliverTx\x12L\n\x07\x43heckTx\x12\x1f.tendermint.abci.RequestCheckTx\x1a .tendermint.abci.ResponseCheckTx\x12\x46\n\x05Query\x12\x1d.tendermint.abci.RequestQuery\x1a\x1e.tendermint.abci.ResponseQuery\x12I\n\x06\x43ommit\x12\x1e.tendermint.abci.RequestCommit\x1a\x1f.tendermint.abci.ResponseCommit\x12R\n\tInitChain\x12!.tendermint.abci.RequestInitChain\x1a\".tendermint.abci.ResponseInitChain\x12U\n\nBeginBlock\x12\".tendermint.abci.RequestBeginBlock\x1a#.tendermint.abci.ResponseBeginBlock\x12O\n\x08\x45ndBlock\x12 .tendermint.abci.RequestEndBlock\x1a!.tendermint.abci.ResponseEndBlock\x12^\n\rListSnapshots\x12%.tendermint.abci.RequestListSnapshots\x1a&.tendermint.abci.ResponseListSnapshots\x12^\n\rOfferSnapshot\x12%.tendermint.abci.RequestOfferSnapshot\x1a&.tendermint.abci.ResponseOfferSnapshot\x12j\n\x11LoadSnapshotChunk\x12).tendermint.abci.RequestLoadSnapshotChunk\x1a*.tendermint.abci.ResponseLoadSnapshotChunk\x12m\n\x12\x41pplySnapshotChunk\x12*.tendermint.abci.RequestApplySnapshotChunk\x1a+.tendermint.abci.ResponseApplySnapshotChunkB-Z+github.com/tendermint/tendermint/abci/typesb\x06proto3')

_CHECKTXTYPE = DESCRIPTOR.enum_types_by_name['CheckTxType']
CheckTxType = enum_type_wrapper.EnumTypeWrapper(_CHECKTXTYPE)
_EVIDENCETYPE = DESCRIPTOR.enum_types_by_name['EvidenceType']
EvidenceType = enum_type_wrapper.EnumTypeWrapper(_EVIDENCETYPE)
NEW = 0
RECHECK = 1
UNKNOWN = 0
DUPLICATE_VOTE = 1
LIGHT_CLIENT_ATTACK = 2


_REQUEST = DESCRIPTOR.message_types_by_name['Request']
_REQUESTECHO = DESCRIPTOR.message_types_by_name['RequestEcho']
_REQUESTFLUSH = DESCRIPTOR.message_types_by_name['RequestFlush']
_REQUESTINFO = DESCRIPTOR.message_types_by_name['RequestInfo']
_REQUESTSETOPTION = DESCRIPTOR.message_types_by_name['RequestSetOption']
_REQUESTINITCHAIN = DESCRIPTOR.message_types_by_name['RequestInitChain']
_REQUESTQUERY = DESCRIPTOR.message_types_by_name['RequestQuery']
_REQUESTBEGINBLOCK = DESCRIPTOR.message_types_by_name['RequestBeginBlock']
_REQUESTCHECKTX = DESCRIPTOR.message_types_by_name['RequestCheckTx']
_REQUESTDELIVERTX = DESCRIPTOR.message_types_by_name['RequestDeliverTx']
_REQUESTENDBLOCK = DESCRIPTOR.message_types_by_name['RequestEndBlock']
_REQUESTCOMMIT = DESCRIPTOR.message_types_by_name['RequestCommit']
_REQUESTLISTSNAPSHOTS = DESCRIPTOR.message_types_by_name['RequestListSnapshots']
_REQUESTOFFERSNAPSHOT = DESCRIPTOR.message_types_by_name['RequestOfferSnapshot']
_REQUESTLOADSNAPSHOTCHUNK = DESCRIPTOR.message_types_by_name['RequestLoadSnapshotChunk']
_REQUESTAPPLYSNAPSHOTCHUNK = DESCRIPTOR.message_types_by_name['RequestApplySnapshotChunk']
_RESPONSE = DESCRIPTOR.message_types_by_name['Response']
_RESPONSEEXCEPTION = DESCRIPTOR.message_types_by_name['ResponseException']
_RESPONSEECHO = DESCRIPTOR.message_types_by_name['ResponseEcho']
_RESPONSEFLUSH = DESCRIPTOR.message_types_by_name['ResponseFlush']
_RESPONSEINFO = DESCRIPTOR.message_types_by_name['ResponseInfo']
_RESPONSESETOPTION = DESCRIPTOR.message_types_by_name['ResponseSetOption']
_RESPONSEINITCHAIN = DESCRIPTOR.message_types_by_name['ResponseInitChain']
_RESPONSEQUERY = DESCRIPTOR.message_types_by_name['ResponseQuery']
_RESPONSEBEGINBLOCK = DESCRIPTOR.message_types_by_name['ResponseBeginBlock']
_RESPONSECHECKTX = DESCRIPTOR.message_types_by_name['ResponseCheckTx']
_RESPONSEDELIVERTX = DESCRIPTOR.message_types_by_name['ResponseDeliverTx']
_RESPONSEENDBLOCK = DESCRIPTOR.message_types_by_name['ResponseEndBlock']
_RESPONSECOMMIT = DESCRIPTOR.message_types_by_name['ResponseCommit']
_RESPONSELISTSNAPSHOTS = DESCRIPTOR.message_types_by_name['ResponseListSnapshots']
_RESPONSEOFFERSNAPSHOT = DESCRIPTOR.message_types_by_name['ResponseOfferSnapshot']
_RESPONSELOADSNAPSHOTCHUNK = DESCRIPTOR.message_types_by_name['ResponseLoadSnapshotChunk']
_RESPONSEAPPLYSNAPSHOTCHUNK = DESCRIPTOR.message_types_by_name['ResponseApplySnapshotChunk']
_CONSENSUSPARAMS = DESCRIPTOR.message_types_by_name['ConsensusParams']
_BLOCKPARAMS = DESCRIPTOR.message_types_by_name['BlockParams']
_LASTCOMMITINFO = DESCRIPTOR.message_types_by_name['LastCommitInfo']
_EVENT = DESCRIPTOR.message_types_by_name['Event']
_EVENTATTRIBUTE = DESCRIPTOR.message_types_by_name['EventAttribute']
_TXRESULT = DESCRIPTOR.message_types_by_name['TxResult']
_VALIDATOR = DESCRIPTOR.message_types_by_name['Validator']
_VALIDATORUPDATE = DESCRIPTOR.message_types_by_name['ValidatorUpdate']
_VOTEINFO = DESCRIPTOR.message_types_by_name['VoteInfo']
_EVIDENCE = DESCRIPTOR.message_types_by_name['Evidence']
_SNAPSHOT = DESCRIPTOR.message_types_by_name['Snapshot']
_RESPONSEOFFERSNAPSHOT_RESULT = _RESPONSEOFFERSNAPSHOT.enum_types_by_name['Result']
_RESPONSEAPPLYSNAPSHOTCHUNK_RESULT = _RESPONSEAPPLYSNAPSHOTCHUNK.enum_types_by_name['Result']
Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.Request)
  })
_sym_db.RegisterMessage(Request)

RequestEcho = _reflection.GeneratedProtocolMessageType('RequestEcho', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTECHO,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestEcho)
  })
_sym_db.RegisterMessage(RequestEcho)

RequestFlush = _reflection.GeneratedProtocolMessageType('RequestFlush', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTFLUSH,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestFlush)
  })
_sym_db.RegisterMessage(RequestFlush)

RequestInfo = _reflection.GeneratedProtocolMessageType('RequestInfo', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTINFO,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestInfo)
  })
_sym_db.RegisterMessage(RequestInfo)

RequestSetOption = _reflection.GeneratedProtocolMessageType('RequestSetOption', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTSETOPTION,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestSetOption)
  })
_sym_db.RegisterMessage(RequestSetOption)

RequestInitChain = _reflection.GeneratedProtocolMessageType('RequestInitChain', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTINITCHAIN,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestInitChain)
  })
_sym_db.RegisterMessage(RequestInitChain)

RequestQuery = _reflection.GeneratedProtocolMessageType('RequestQuery', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTQUERY,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestQuery)
  })
_sym_db.RegisterMessage(RequestQuery)

RequestBeginBlock = _reflection.GeneratedProtocolMessageType('RequestBeginBlock', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTBEGINBLOCK,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestBeginBlock)
  })
_sym_db.RegisterMessage(RequestBeginBlock)

RequestCheckTx = _reflection.GeneratedProtocolMessageType('RequestCheckTx', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTCHECKTX,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestCheckTx)
  })
_sym_db.RegisterMessage(RequestCheckTx)

RequestDeliverTx = _reflection.GeneratedProtocolMessageType('RequestDeliverTx', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDELIVERTX,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestDeliverTx)
  })
_sym_db.RegisterMessage(RequestDeliverTx)

RequestEndBlock = _reflection.GeneratedProtocolMessageType('RequestEndBlock', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTENDBLOCK,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestEndBlock)
  })
_sym_db.RegisterMessage(RequestEndBlock)

RequestCommit = _reflection.GeneratedProtocolMessageType('RequestCommit', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTCOMMIT,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestCommit)
  })
_sym_db.RegisterMessage(RequestCommit)

RequestListSnapshots = _reflection.GeneratedProtocolMessageType('RequestListSnapshots', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTLISTSNAPSHOTS,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestListSnapshots)
  })
_sym_db.RegisterMessage(RequestListSnapshots)

RequestOfferSnapshot = _reflection.GeneratedProtocolMessageType('RequestOfferSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTOFFERSNAPSHOT,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestOfferSnapshot)
  })
_sym_db.RegisterMessage(RequestOfferSnapshot)

RequestLoadSnapshotChunk = _reflection.GeneratedProtocolMessageType('RequestLoadSnapshotChunk', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTLOADSNAPSHOTCHUNK,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestLoadSnapshotChunk)
  })
_sym_db.RegisterMessage(RequestLoadSnapshotChunk)

RequestApplySnapshotChunk = _reflection.GeneratedProtocolMessageType('RequestApplySnapshotChunk', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTAPPLYSNAPSHOTCHUNK,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.RequestApplySnapshotChunk)
  })
_sym_db.RegisterMessage(RequestApplySnapshotChunk)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.Response)
  })
_sym_db.RegisterMessage(Response)

ResponseException = _reflection.GeneratedProtocolMessageType('ResponseException', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEEXCEPTION,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseException)
  })
_sym_db.RegisterMessage(ResponseException)

ResponseEcho = _reflection.GeneratedProtocolMessageType('ResponseEcho', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEECHO,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseEcho)
  })
_sym_db.RegisterMessage(ResponseEcho)

ResponseFlush = _reflection.GeneratedProtocolMessageType('ResponseFlush', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEFLUSH,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseFlush)
  })
_sym_db.RegisterMessage(ResponseFlush)

ResponseInfo = _reflection.GeneratedProtocolMessageType('ResponseInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEINFO,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseInfo)
  })
_sym_db.RegisterMessage(ResponseInfo)

ResponseSetOption = _reflection.GeneratedProtocolMessageType('ResponseSetOption', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSESETOPTION,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseSetOption)
  })
_sym_db.RegisterMessage(ResponseSetOption)

ResponseInitChain = _reflection.GeneratedProtocolMessageType('ResponseInitChain', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEINITCHAIN,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseInitChain)
  })
_sym_db.RegisterMessage(ResponseInitChain)

ResponseQuery = _reflection.GeneratedProtocolMessageType('ResponseQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEQUERY,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseQuery)
  })
_sym_db.RegisterMessage(ResponseQuery)

ResponseBeginBlock = _reflection.GeneratedProtocolMessageType('ResponseBeginBlock', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEBEGINBLOCK,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseBeginBlock)
  })
_sym_db.RegisterMessage(ResponseBeginBlock)

ResponseCheckTx = _reflection.GeneratedProtocolMessageType('ResponseCheckTx', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSECHECKTX,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseCheckTx)
  })
_sym_db.RegisterMessage(ResponseCheckTx)

ResponseDeliverTx = _reflection.GeneratedProtocolMessageType('ResponseDeliverTx', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEDELIVERTX,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseDeliverTx)
  })
_sym_db.RegisterMessage(ResponseDeliverTx)

ResponseEndBlock = _reflection.GeneratedProtocolMessageType('ResponseEndBlock', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEENDBLOCK,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseEndBlock)
  })
_sym_db.RegisterMessage(ResponseEndBlock)

ResponseCommit = _reflection.GeneratedProtocolMessageType('ResponseCommit', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSECOMMIT,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseCommit)
  })
_sym_db.RegisterMessage(ResponseCommit)

ResponseListSnapshots = _reflection.GeneratedProtocolMessageType('ResponseListSnapshots', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSELISTSNAPSHOTS,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseListSnapshots)
  })
_sym_db.RegisterMessage(ResponseListSnapshots)

ResponseOfferSnapshot = _reflection.GeneratedProtocolMessageType('ResponseOfferSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEOFFERSNAPSHOT,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseOfferSnapshot)
  })
_sym_db.RegisterMessage(ResponseOfferSnapshot)

ResponseLoadSnapshotChunk = _reflection.GeneratedProtocolMessageType('ResponseLoadSnapshotChunk', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSELOADSNAPSHOTCHUNK,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseLoadSnapshotChunk)
  })
_sym_db.RegisterMessage(ResponseLoadSnapshotChunk)

ResponseApplySnapshotChunk = _reflection.GeneratedProtocolMessageType('ResponseApplySnapshotChunk', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEAPPLYSNAPSHOTCHUNK,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseApplySnapshotChunk)
  })
_sym_db.RegisterMessage(ResponseApplySnapshotChunk)

ConsensusParams = _reflection.GeneratedProtocolMessageType('ConsensusParams', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSPARAMS,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ConsensusParams)
  })
_sym_db.RegisterMessage(ConsensusParams)

BlockParams = _reflection.GeneratedProtocolMessageType('BlockParams', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKPARAMS,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.BlockParams)
  })
_sym_db.RegisterMessage(BlockParams)

LastCommitInfo = _reflection.GeneratedProtocolMessageType('LastCommitInfo', (_message.Message,), {
  'DESCRIPTOR' : _LASTCOMMITINFO,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.LastCommitInfo)
  })
_sym_db.RegisterMessage(LastCommitInfo)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.Event)
  })
_sym_db.RegisterMessage(Event)

EventAttribute = _reflection.GeneratedProtocolMessageType('EventAttribute', (_message.Message,), {
  'DESCRIPTOR' : _EVENTATTRIBUTE,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.EventAttribute)
  })
_sym_db.RegisterMessage(EventAttribute)

TxResult = _reflection.GeneratedProtocolMessageType('TxResult', (_message.Message,), {
  'DESCRIPTOR' : _TXRESULT,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.TxResult)
  })
_sym_db.RegisterMessage(TxResult)

Validator = _reflection.GeneratedProtocolMessageType('Validator', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATOR,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.Validator)
  })
_sym_db.RegisterMessage(Validator)

ValidatorUpdate = _reflection.GeneratedProtocolMessageType('ValidatorUpdate', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORUPDATE,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.ValidatorUpdate)
  })
_sym_db.RegisterMessage(ValidatorUpdate)

VoteInfo = _reflection.GeneratedProtocolMessageType('VoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _VOTEINFO,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.VoteInfo)
  })
_sym_db.RegisterMessage(VoteInfo)

Evidence = _reflection.GeneratedProtocolMessageType('Evidence', (_message.Message,), {
  'DESCRIPTOR' : _EVIDENCE,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.Evidence)
  })
_sym_db.RegisterMessage(Evidence)

Snapshot = _reflection.GeneratedProtocolMessageType('Snapshot', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOT,
  '__module__' : 'tendermint.abci.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.abci.Snapshot)
  })
_sym_db.RegisterMessage(Snapshot)

_ABCIAPPLICATION = DESCRIPTOR.services_by_name['ABCIApplication']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/tendermint/tendermint/abci/types'
  _CHECKTXTYPE.values_by_name["NEW"]._options = None
  _CHECKTXTYPE.values_by_name["NEW"]._serialized_options = b'\212\235 \003New'
  _CHECKTXTYPE.values_by_name["RECHECK"]._options = None
  _CHECKTXTYPE.values_by_name["RECHECK"]._serialized_options = b'\212\235 \007Recheck'
  _REQUESTINITCHAIN.fields_by_name['time']._options = None
  _REQUESTINITCHAIN.fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _REQUESTINITCHAIN.fields_by_name['validators']._options = None
  _REQUESTINITCHAIN.fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _REQUESTBEGINBLOCK.fields_by_name['header']._options = None
  _REQUESTBEGINBLOCK.fields_by_name['header']._serialized_options = b'\310\336\037\000'
  _REQUESTBEGINBLOCK.fields_by_name['last_commit_info']._options = None
  _REQUESTBEGINBLOCK.fields_by_name['last_commit_info']._serialized_options = b'\310\336\037\000'
  _REQUESTBEGINBLOCK.fields_by_name['byzantine_validators']._options = None
  _REQUESTBEGINBLOCK.fields_by_name['byzantine_validators']._serialized_options = b'\310\336\037\000'
  _RESPONSEINITCHAIN.fields_by_name['validators']._options = None
  _RESPONSEINITCHAIN.fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _RESPONSEBEGINBLOCK.fields_by_name['events']._options = None
  _RESPONSEBEGINBLOCK.fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _RESPONSECHECKTX.fields_by_name['events']._options = None
  _RESPONSECHECKTX.fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _RESPONSEDELIVERTX.fields_by_name['events']._options = None
  _RESPONSEDELIVERTX.fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _RESPONSEENDBLOCK.fields_by_name['validator_updates']._options = None
  _RESPONSEENDBLOCK.fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _RESPONSEENDBLOCK.fields_by_name['events']._options = None
  _RESPONSEENDBLOCK.fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _LASTCOMMITINFO.fields_by_name['votes']._options = None
  _LASTCOMMITINFO.fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _EVENT.fields_by_name['attributes']._options = None
  _EVENT.fields_by_name['attributes']._serialized_options = b'\310\336\037\000\352\336\037\024attributes,omitempty'
  _TXRESULT.fields_by_name['result']._options = None
  _TXRESULT.fields_by_name['result']._serialized_options = b'\310\336\037\000'
  _VALIDATORUPDATE.fields_by_name['pub_key']._options = None
  _VALIDATORUPDATE.fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _VOTEINFO.fields_by_name['validator']._options = None
  _VOTEINFO.fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _EVIDENCE.fields_by_name['validator']._options = None
  _EVIDENCE.fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _EVIDENCE.fields_by_name['time']._options = None
  _EVIDENCE.fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _CHECKTXTYPE._serialized_start=6314
  _CHECKTXTYPE._serialized_end=6371
  _EVIDENCETYPE._serialized_start=6373
  _EVIDENCETYPE._serialized_end=6445
  _REQUEST._serialized_start=226
  _REQUEST._serialized_end=1100
  _REQUESTECHO._serialized_start=1102
  _REQUESTECHO._serialized_end=1132
  _REQUESTFLUSH._serialized_start=1134
  _REQUESTFLUSH._serialized_end=1148
  _REQUESTINFO._serialized_start=1150
  _REQUESTINFO._serialized_end=1224
  _REQUESTSETOPTION._serialized_start=1226
  _REQUESTSETOPTION._serialized_end=1272
  _REQUESTINITCHAIN._serialized_start=1275
  _REQUESTINITCHAIN._serialized_end=1532
  _REQUESTQUERY._serialized_start=1534
  _REQUESTQUERY._serialized_end=1607
  _REQUESTBEGINBLOCK._serialized_start=1610
  _REQUESTBEGINBLOCK._serialized_end=1819
  _REQUESTCHECKTX._serialized_start=1821
  _REQUESTCHECKTX._serialized_end=1893
  _REQUESTDELIVERTX._serialized_start=1895
  _REQUESTDELIVERTX._serialized_end=1925
  _REQUESTENDBLOCK._serialized_start=1927
  _REQUESTENDBLOCK._serialized_end=1960
  _REQUESTCOMMIT._serialized_start=1962
  _REQUESTCOMMIT._serialized_end=1977
  _REQUESTLISTSNAPSHOTS._serialized_start=1979
  _REQUESTLISTSNAPSHOTS._serialized_end=2001
  _REQUESTOFFERSNAPSHOT._serialized_start=2003
  _REQUESTOFFERSNAPSHOT._serialized_end=2088
  _REQUESTLOADSNAPSHOTCHUNK._serialized_start=2090
  _REQUESTLOADSNAPSHOTCHUNK._serialized_end=2163
  _REQUESTAPPLYSNAPSHOTCHUNK._serialized_start=2165
  _REQUESTAPPLYSNAPSHOTCHUNK._serialized_end=2238
  _RESPONSE._serialized_start=2241
  _RESPONSE._serialized_end=3188
  _RESPONSEEXCEPTION._serialized_start=3190
  _RESPONSEEXCEPTION._serialized_end=3224
  _RESPONSEECHO._serialized_start=3226
  _RESPONSEECHO._serialized_end=3257
  _RESPONSEFLUSH._serialized_start=3259
  _RESPONSEFLUSH._serialized_end=3274
  _RESPONSEINFO._serialized_start=3276
  _RESPONSEINFO._serialized_end=3398
  _RESPONSESETOPTION._serialized_start=3400
  _RESPONSESETOPTION._serialized_end=3460
  _RESPONSEINITCHAIN._serialized_start=3463
  _RESPONSEINITCHAIN._serialized_end=3620
  _RESPONSEQUERY._serialized_start=3623
  _RESPONSEQUERY._serialized_end=3805
  _RESPONSEBEGINBLOCK._serialized_start=3807
  _RESPONSEBEGINBLOCK._serialized_end=3893
  _RESPONSECHECKTX._serialized_start=3896
  _RESPONSECHECKTX._serialized_end=4113
  _RESPONSEDELIVERTX._serialized_start=4116
  _RESPONSEDELIVERTX._serialized_end=4335
  _RESPONSEENDBLOCK._serialized_start=4338
  _RESPONSEENDBLOCK._serialized_end=4556
  _RESPONSECOMMIT._serialized_start=4558
  _RESPONSECOMMIT._serialized_end=4611
  _RESPONSELISTSNAPSHOTS._serialized_start=4613
  _RESPONSELISTSNAPSHOTS._serialized_end=4682
  _RESPONSEOFFERSNAPSHOT._serialized_start=4685
  _RESPONSEOFFERSNAPSHOT._serialized_end=4867
  _RESPONSEOFFERSNAPSHOT_RESULT._serialized_start=4773
  _RESPONSEOFFERSNAPSHOT_RESULT._serialized_end=4867
  _RESPONSELOADSNAPSHOTCHUNK._serialized_start=4869
  _RESPONSELOADSNAPSHOTCHUNK._serialized_end=4911
  _RESPONSEAPPLYSNAPSHOTCHUNK._serialized_start=4914
  _RESPONSEAPPLYSNAPSHOTCHUNK._serialized_end=5156
  _RESPONSEAPPLYSNAPSHOTCHUNK_RESULT._serialized_start=5060
  _RESPONSEAPPLYSNAPSHOTCHUNK_RESULT._serialized_end=5156
  _CONSENSUSPARAMS._serialized_start=5159
  _CONSENSUSPARAMS._serialized_end=5377
  _BLOCKPARAMS._serialized_start=5379
  _BLOCKPARAMS._serialized_end=5428
  _LASTCOMMITINFO._serialized_start=5430
  _LASTCOMMITINFO._serialized_end=5509
  _EVENT._serialized_start=5511
  _EVENT._serialized_end=5615
  _EVENTATTRIBUTE._serialized_start=5617
  _EVENTATTRIBUTE._serialized_end=5676
  _TXRESULT._serialized_start=5678
  _TXRESULT._serialized_end=5789
  _VALIDATOR._serialized_start=5791
  _VALIDATOR._serialized_end=5834
  _VALIDATORUPDATE._serialized_start=5836
  _VALIDATORUPDATE._serialized_end=5921
  _VOTEINFO._serialized_start=5923
  _VOTEINFO._serialized_end=6013
  _EVIDENCE._serialized_start=6016
  _EVIDENCE._serialized_end=6220
  _SNAPSHOT._serialized_start=6222
  _SNAPSHOT._serialized_end=6312
  _ABCIAPPLICATION._serialized_start=6448
  _ABCIAPPLICATION._serialized_end=7731
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from stablecoin import query_pb2 as stablecoin_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/nibiru.stablecoin.v1.Query/Params',
                request_serializer=stablecoin_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=stablecoin_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.ModuleAccountBalances = channel.unary_unary(
                '/nibiru.stablecoin.v1.Query/ModuleAccountBalances',
                request_serializer=stablecoin_dot_query__pb2.QueryModuleAccountBalances.SerializeToString,
                response_deserializer=stablecoin_dot_query__pb2.QueryModuleAccountBalancesResponse.FromString,
                )
        self.CirculatingSupplies = channel.unary_unary(
                '/nibiru.stablecoin.v1.Query/CirculatingSupplies',
                request_serializer=stablecoin_dot_query__pb2.QueryCirculatingSupplies.SerializeToString,
                response_deserializer=stablecoin_dot_query__pb2.QueryCirculatingSuppliesResponse.FromString,
                )
        self.LiquidityRatioInfo = channel.unary_unary(
                '/nibiru.stablecoin.v1.Query/LiquidityRatioInfo',
                request_serializer=stablecoin_dot_query__pb2.QueryLiquidityRatioInfoRequest.SerializeToString,
                response_deserializer=stablecoin_dot_query__pb2.QueryLiquidityRatioInfoResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Parameters queries the parameters of the x/stablecoin module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModuleAccountBalances(self, request, context):
        """ModuleAccountBalances queries the account balance of x/stablecoin.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CirculatingSupplies(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LiquidityRatioInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=stablecoin_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=stablecoin_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'ModuleAccountBalances': grpc.unary_unary_rpc_method_handler(
                    servicer.ModuleAccountBalances,
                    request_deserializer=stablecoin_dot_query__pb2.QueryModuleAccountBalances.FromString,
                    response_serializer=stablecoin_dot_query__pb2.QueryModuleAccountBalancesResponse.SerializeToString,
            ),
            'CirculatingSupplies': grpc.unary_unary_rpc_method_handler(
                    servicer.CirculatingSupplies,
                    request_deserializer=stablecoin_dot_query__pb2.QueryCirculatingSupplies.FromString,
                    response_serializer=stablecoin_dot_query__pb2.QueryCirculatingSuppliesResponse.SerializeToString,
            ),
            'LiquidityRatioInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.LiquidityRatioInfo,
                    request_deserializer=stablecoin_dot_query__pb2.QueryLiquidityRatioInfoRequest.FromString,
                    response_serializer=stablecoin_dot_query__pb2.QueryLiquidityRatioInfoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.stablecoin.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Query/Params',
            stablecoin_dot_query__pb2.QueryParamsRequest.SerializeToString,
            stablecoin_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ModuleAccountBalances(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Query/ModuleAccountBalances',
            stablecoin_dot_query__pb2.QueryModuleAccountBalances.SerializeToString,
            stablecoin_dot_query__pb2.QueryModuleAccountBalancesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CirculatingSupplies(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Query/CirculatingSupplies',
            stablecoin_dot_query__pb2.QueryCirculatingSupplies.SerializeToString,
            stablecoin_dot_query__pb2.QueryCirculatingSuppliesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LiquidityRatioInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Query/LiquidityRatioInfo',
            stablecoin_dot_query__pb2.QueryLiquidityRatioInfoRequest.SerializeToString,
            stablecoin_dot_query__pb2.QueryLiquidityRatioInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/genutil/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/genutil/v1beta1/genesis.proto\x12\x16\x63osmos.genutil.v1beta1\x1a\x14gogoproto/gogo.proto\"X\n\x0cGenesisState\x12H\n\x07gen_txs\x18\x01 \x03(\x0c\x42\x37\xfa\xde\x1f\x18\x65ncoding/json.RawMessage\xea\xde\x1f\x06gentxs\xf2\xde\x1f\ryaml:\"gentxs\"B.Z,github.com/cosmos/cosmos-sdk/x/genutil/typesb\x06proto3')



_GENESISSTATE = DESCRIPTOR.message_types_by_name['GenesisState']
GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'cosmos.genutil.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.genutil.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/genutil/types'
  _GENESISSTATE.fields_by_name['gen_txs']._options = None
  _GENESISSTATE.fields_by_name['gen_txs']._serialized_options = b'\372\336\037\030encoding/json.RawMessage\352\336\037\006gentxs\362\336\037\ryaml:\"gentxs\"'
  _GENESISSTATE._serialized_start=86
  _GENESISSTATE._serialized_end=174
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/params/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.params.v1beta1 import params_pb2 as cosmos_dot_params_dot_v1beta1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/params/v1beta1/query.proto\x12\x15\x63osmos.params.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\"cosmos/params/v1beta1/params.proto\"3\n\x12QueryParamsRequest\x12\x10\n\x08subspace\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"N\n\x13QueryParamsResponse\x12\x37\n\x05param\x18\x01 \x01(\x0b\x32\".cosmos.params.v1beta1.ParamChangeB\x04\xc8\xde\x1f\x00\x32\x90\x01\n\x05Query\x12\x86\x01\n\x06Params\x12).cosmos.params.v1beta1.QueryParamsRequest\x1a*.cosmos.params.v1beta1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cosmos/params/v1beta1/paramsB6Z4github.com/cosmos/cosmos-sdk/x/params/types/proposalb\x06proto3')



_QUERYPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryParamsRequest']
_QUERYPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryParamsResponse']
QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'cosmos.params.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.params.v1beta1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'cosmos.params.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.params.v1beta1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal'
  _QUERYPARAMSRESPONSE.fields_by_name['param']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['param']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\037\022\035/cosmos/params/v1beta1/params'
  _QUERYPARAMSREQUEST._serialized_start=148
  _QUERYPARAMSREQUEST._serialized_end=199
  _QUERYPARAMSRESPONSE._serialized_start=201
  _QUERYPARAMSRESPONSE._serialized_end=279
  _QUERY._serialized_start=282
  _QUERY._serialized_end=426
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from incentivization.v1 import incentivization_pb2 as incentivization_dot_v1_dot_incentivization__pb2


class MsgStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateIncentivizationProgram = channel.unary_unary(
                '/nibiru.incentivization.v1.Msg/CreateIncentivizationProgram',
                request_serializer=incentivization_dot_v1_dot_incentivization__pb2.MsgCreateIncentivizationProgram.SerializeToString,
                response_deserializer=incentivization_dot_v1_dot_incentivization__pb2.MsgCreateIncentivizationProgramResponse.FromString,
                )
        self.FundIncentivizationProgram = channel.unary_unary(
                '/nibiru.incentivization.v1.Msg/FundIncentivizationProgram',
                request_serializer=incentivization_dot_v1_dot_incentivization__pb2.MsgFundIncentivizationProgram.SerializeToString,
                response_deserializer=incentivization_dot_v1_dot_incentivization__pb2.MsgFundIncentivizationProgramResponse.FromString,
                )


class MsgServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateIncentivizationProgram(self, request, context):
        """CreateIncentivizationProgram allows an entity to create an incentivization program for a liquidity pool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FundIncentivizationProgram(self, request, context):
        """FundIncentivizationProgram allows an entity to fund an already existing incentivization program with more coins.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateIncentivizationProgram': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIncentivizationProgram,
                    request_deserializer=incentivization_dot_v1_dot_incentivization__pb2.MsgCreateIncentivizationProgram.FromString,
                    response_serializer=incentivization_dot_v1_dot_incentivization__pb2.MsgCreateIncentivizationProgramResponse.SerializeToString,
            ),
            'FundIncentivizationProgram': grpc.unary_unary_rpc_method_handler(
                    servicer.FundIncentivizationProgram,
                    request_deserializer=incentivization_dot_v1_dot_incentivization__pb2.MsgFundIncentivizationProgram.FromString,
                    response_serializer=incentivization_dot_v1_dot_incentivization__pb2.MsgFundIncentivizationProgramResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.incentivization.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateIncentivizationProgram(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.incentivization.v1.Msg/CreateIncentivizationProgram',
            incentivization_dot_v1_dot_incentivization__pb2.MsgCreateIncentivizationProgram.SerializeToString,
            incentivization_dot_v1_dot_incentivization__pb2.MsgCreateIncentivizationProgramResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FundIncentivizationProgram(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.incentivization.v1.Msg/FundIncentivizationProgram',
            incentivization_dot_v1_dot_incentivization__pb2.MsgFundIncentivizationProgram.SerializeToString,
            incentivization_dot_v1_dot_incentivization__pb2.MsgFundIncentivizationProgramResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class QueryStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.IncentivizationProgram = channel.unary_unary(
                '/nibiru.incentivization.v1.Query/IncentivizationProgram',
                request_serializer=incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramRequest.SerializeToString,
                response_deserializer=incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramResponse.FromString,
                )
        self.IncentivizationPrograms = channel.unary_unary(
                '/nibiru.incentivization.v1.Query/IncentivizationPrograms',
                request_serializer=incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramsRequest.SerializeToString,
                response_deserializer=incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramsResponse.FromString,
                )


class QueryServicer(object):
    """Missing associated documentation comment in .proto file."""

    def IncentivizationProgram(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IncentivizationPrograms(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'IncentivizationProgram': grpc.unary_unary_rpc_method_handler(
                    servicer.IncentivizationProgram,
                    request_deserializer=incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramRequest.FromString,
                    response_serializer=incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramResponse.SerializeToString,
            ),
            'IncentivizationPrograms': grpc.unary_unary_rpc_method_handler(
                    servicer.IncentivizationPrograms,
                    request_deserializer=incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramsRequest.FromString,
                    response_serializer=incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.incentivization.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def IncentivizationProgram(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.incentivization.v1.Query/IncentivizationProgram',
            incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramRequest.SerializeToString,
            incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IncentivizationPrograms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.incentivization.v1.Query/IncentivizationPrograms',
            incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramsRequest.SerializeToString,
            incentivization_dot_v1_dot_incentivization__pb2.QueryIncentivizationProgramsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dex/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import (
    pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2,
)
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from dex.v1 import params_pb2 as dex_dot_v1_dot_params__pb2
from dex.v1 import pool_pb2 as dex_dot_v1_dot_pool__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x12\x64\x65x/v1/query.proto\x12\rnibiru.dex.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x13\x64\x65x/v1/params.proto\x1a\x11\x64\x65x/v1/pool.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x14\n\x12QueryParamsRequest\"B\n\x13QueryParamsResponse\x12+\n\x06params\x18\x01 \x01(\x0b\x32\x15.nibiru.dex.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x18\n\x16QueryPoolNumberRequest\"*\n\x17QueryPoolNumberResponse\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\"#\n\x10QueryPoolRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\"6\n\x11QueryPoolResponse\x12!\n\x04pool\x18\x01 \x01(\x0b\x32\x13.nibiru.dex.v1.Pool\"O\n\x11QueryPoolsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"u\n\x12QueryPoolsResponse\x12\"\n\x05pools\x18\x01 \x03(\x0b\x32\x13.nibiru.dex.v1.Pool\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\")\n\x16QueryPoolParamsRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\"I\n\x17QueryPoolParamsResponse\x12.\n\x0bpool_params\x18\x01 \x01(\x0b\x32\x19.nibiru.dex.v1.PoolParams\"\x16\n\x14QueryNumPoolsRequest\"*\n\x15QueryNumPoolsResponse\x12\x11\n\tnum_pools\x18\x01 \x01(\x04\"\x1c\n\x1aQueryTotalLiquidityRequest\"\x91\x01\n\x1bQueryTotalLiquidityResponse\x12r\n\tliquidity\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"liquidity\"\xc8\xde\x1f\x00\"1\n\x1eQueryTotalPoolLiquidityRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\"\x95\x01\n\x1fQueryTotalPoolLiquidityResponse\x12r\n\tliquidity\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"liquidity\"\xc8\xde\x1f\x00\"*\n\x17QueryTotalSharesRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\"h\n\x18QueryTotalSharesResponse\x12L\n\x0ctotal_shares\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1b\xf2\xde\x1f\x13yaml:\"total_shares\"\xc8\xde\x1f\x00\"Y\n\x15QuerySpotPriceRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\x12\x16\n\x0etoken_in_denom\x18\x02 \x01(\t\x12\x17\n\x0ftoken_out_denom\x18\x03 \x01(\t\",\n\x16QuerySpotPriceResponse\x12\x12\n\nspot_price\x18\x01 \x01(\t\"\x8f\x01\n\x1dQuerySwapExactAmountInRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\x12\x44\n\x08token_in\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\x12\x17\n\x0ftoken_out_denom\x18\x03 \x01(\t\"h\n\x1eQuerySwapExactAmountInResponse\x12\x46\n\ttoken_out\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\"\x91\x01\n\x1eQuerySwapExactAmountOutRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\x12\x46\n\ttoken_out\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\x12\x16\n\x0etoken_in_denom\x18\x03 \x01(\t\"g\n\x1fQuerySwapExactAmountOutResponse\x12\x44\n\x08token_in\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\"\xa4\x01\n\x1dQueryJoinExactAmountInRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\x12r\n\ttokens_in\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"tokens_in\"\xc8\xde\x1f\x00\"\xf7\x01\n\x1eQueryJoinExactAmountInResponse\x12\x61\n\x0fpool_shares_out\x18\x01 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"pool_shares_out\"\xc8\xde\x1f\x00\x12r\n\trem_coins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"rem_coins\"\xc8\xde\x1f\x00\"1\n\x1eQueryJoinExactAmountOutRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\"!\n\x1fQueryJoinExactAmountOutResponse\"\x91\x01\n\x1dQueryExitExactAmountInRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\x12_\n\x0epool_shares_in\x18\x02 \x01(\tBG\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x15yaml:\"pool_shares_in\"\xc8\xde\x1f\x00\"\x96\x01\n\x1eQueryExitExactAmountInResponse\x12t\n\ntokens_out\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBE\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x11yaml:\"tokens_out\"\xc8\xde\x1f\x00\"1\n\x1eQueryExitExactAmountOutRequest\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\"!\n\x1fQueryExitExactAmountOutResponse2\xf5\x12\n\x05Query\x12k\n\x06Params\x12!.nibiru.dex.v1.QueryParamsRequest\x1a\".nibiru.dex.v1.QueryParamsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/nibiru/dex/params\x12|\n\nPoolNumber\x12%.nibiru.dex.v1.QueryPoolNumberRequest\x1a&.nibiru.dex.v1.QueryPoolNumberResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/nibiru/dex/pool_number\x12\x63\n\x04Pool\x12\x1f.nibiru.dex.v1.QueryPoolRequest\x1a .nibiru.dex.v1.QueryPoolResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/nibiru/dex/pool\x12g\n\x05Pools\x12 .nibiru.dex.v1.QueryPoolsRequest\x1a!.nibiru.dex.v1.QueryPoolsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/nibiru/dex/pools\x12\x87\x01\n\nPoolParams\x12%.nibiru.dex.v1.QueryPoolParamsRequest\x1a&.nibiru.dex.v1.QueryPoolParamsResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/nibiru/dex/pools/{pool_id}/params\x12t\n\x08NumPools\x12#.nibiru.dex.v1.QueryNumPoolsRequest\x1a$.nibiru.dex.v1.QueryNumPoolsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/nibiru/dex/num_pools\x12\x8c\x01\n\x0eTotalLiquidity\x12).nibiru.dex.v1.QueryTotalLiquidityRequest\x1a*.nibiru.dex.v1.QueryTotalLiquidityResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/nibiru/dex/total_liquidity\x12\xad\x01\n\x12TotalPoolLiquidity\x12-.nibiru.dex.v1.QueryTotalPoolLiquidityRequest\x1a..nibiru.dex.v1.QueryTotalPoolLiquidityResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/nibiru/dex/pools/{pool_id}/total_pool_liquidity\x12\x90\x01\n\x0bTotalShares\x12&.nibiru.dex.v1.QueryTotalSharesRequest\x1a\'.nibiru.dex.v1.QueryTotalSharesResponse\"0\x82\xd3\xe4\x93\x02*\x12(/nibiru/dex/pools/{pool_id}/total_shares\x12\x84\x01\n\tSpotPrice\x12$.nibiru.dex.v1.QuerySpotPriceRequest\x1a%.nibiru.dex.v1.QuerySpotPriceResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/nibiru/dex/pools/{pool_id}/prices\x12\xb5\x01\n\x19\x45stimateSwapExactAmountIn\x12,.nibiru.dex.v1.QuerySwapExactAmountInRequest\x1a-.nibiru.dex.v1.QuerySwapExactAmountInResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/nibiru/dex/{pool_id}/estimate/swap_exact_amount_in\x12\xb9\x01\n\x1a\x45stimateSwapExactAmountOut\x12-.nibiru.dex.v1.QuerySwapExactAmountOutRequest\x1a..nibiru.dex.v1.QuerySwapExactAmountOutResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/nibiru/dex/{pool_id}/estimate/swap_exact_amount_out\x12\xb5\x01\n\x19\x45stimateJoinExactAmountIn\x12,.nibiru.dex.v1.QueryJoinExactAmountInRequest\x1a-.nibiru.dex.v1.QueryJoinExactAmountInResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/nibiru/dex/{pool_id}/estimate/join_exact_amount_in\x12\xb9\x01\n\x1a\x45stimateJoinExactAmountOut\x12-.nibiru.dex.v1.QueryJoinExactAmountOutRequest\x1a..nibiru.dex.v1.QueryJoinExactAmountOutResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/nibiru/dex/{pool_id}/estimate/join_exact_amount_out\x12\xb5\x01\n\x19\x45stimateExitExactAmountIn\x12,.nibiru.dex.v1.QueryExitExactAmountInRequest\x1a-.nibiru.dex.v1.QueryExitExactAmountInResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/nibiru/dex/{pool_id}/estimate/exit_exact_amount_in\x12\xb9\x01\n\x1a\x45stimateExitExactAmountOut\x12-.nibiru.dex.v1.QueryExitExactAmountOutRequest\x1a..nibiru.dex.v1.QueryExitExactAmountOutResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/nibiru/dex/{pool_id}/estimate/exit_exact_amount_outB+Z)github.com/NibiruChain/nibiru/x/dex/typesb\x06proto3'
)


_QUERYPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryParamsRequest']
_QUERYPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryParamsResponse']
_QUERYPOOLNUMBERREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolNumberRequest']
_QUERYPOOLNUMBERRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolNumberResponse']
_QUERYPOOLREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolRequest']
_QUERYPOOLRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolResponse']
_QUERYPOOLSREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolsRequest']
_QUERYPOOLSRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolsResponse']
_QUERYPOOLPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolParamsRequest']
_QUERYPOOLPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolParamsResponse']
_QUERYNUMPOOLSREQUEST = DESCRIPTOR.message_types_by_name['QueryNumPoolsRequest']
_QUERYNUMPOOLSRESPONSE = DESCRIPTOR.message_types_by_name['QueryNumPoolsResponse']
_QUERYTOTALLIQUIDITYREQUEST = DESCRIPTOR.message_types_by_name['QueryTotalLiquidityRequest']
_QUERYTOTALLIQUIDITYRESPONSE = DESCRIPTOR.message_types_by_name['QueryTotalLiquidityResponse']
_QUERYTOTALPOOLLIQUIDITYREQUEST = DESCRIPTOR.message_types_by_name['QueryTotalPoolLiquidityRequest']
_QUERYTOTALPOOLLIQUIDITYRESPONSE = DESCRIPTOR.message_types_by_name['QueryTotalPoolLiquidityResponse']
_QUERYTOTALSHARESREQUEST = DESCRIPTOR.message_types_by_name['QueryTotalSharesRequest']
_QUERYTOTALSHARESRESPONSE = DESCRIPTOR.message_types_by_name['QueryTotalSharesResponse']
_QUERYSPOTPRICEREQUEST = DESCRIPTOR.message_types_by_name['QuerySpotPriceRequest']
_QUERYSPOTPRICERESPONSE = DESCRIPTOR.message_types_by_name['QuerySpotPriceResponse']
_QUERYSWAPEXACTAMOUNTINREQUEST = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountInRequest']
_QUERYSWAPEXACTAMOUNTINRESPONSE = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountInResponse']
_QUERYSWAPEXACTAMOUNTOUTREQUEST = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountOutRequest']
_QUERYSWAPEXACTAMOUNTOUTRESPONSE = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountOutResponse']
_QUERYJOINEXACTAMOUNTINREQUEST = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountInRequest']
_QUERYJOINEXACTAMOUNTINRESPONSE = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountInResponse']
_QUERYJOINEXACTAMOUNTOUTREQUEST = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountOutRequest']
_QUERYJOINEXACTAMOUNTOUTRESPONSE = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountOutResponse']
_QUERYEXITEXACTAMOUNTINREQUEST = DESCRIPTOR.message_types_by_name['QueryExitExactAmountInRequest']
_QUERYEXITEXACTAMOUNTINRESPONSE = DESCRIPTOR.message_types_by_name['QueryExitExactAmountInResponse']
_QUERYEXITEXACTAMOUNTOUTREQUEST = DESCRIPTOR.message_types_by_name['QueryExitExactAmountOutRequest']
_QUERYEXITEXACTAMOUNTOUTRESPONSE = DESCRIPTOR.message_types_by_name['QueryExitExactAmountOutResponse']
QueryParamsRequest = _reflection.GeneratedProtocolMessageType(
    'QueryParamsRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPARAMSREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryParamsRequest)
    },
)
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType(
    'QueryParamsResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPARAMSRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryParamsResponse)
    },
)
_sym_db.RegisterMessage(QueryParamsResponse)

QueryPoolNumberRequest = _reflection.GeneratedProtocolMessageType(
    'QueryPoolNumberRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPOOLNUMBERREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolNumberRequest)
    },
)
_sym_db.RegisterMessage(QueryPoolNumberRequest)

QueryPoolNumberResponse = _reflection.GeneratedProtocolMessageType(
    'QueryPoolNumberResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPOOLNUMBERRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolNumberResponse)
    },
)
_sym_db.RegisterMessage(QueryPoolNumberResponse)

QueryPoolRequest = _reflection.GeneratedProtocolMessageType(
    'QueryPoolRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPOOLREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolRequest)
    },
)
_sym_db.RegisterMessage(QueryPoolRequest)

QueryPoolResponse = _reflection.GeneratedProtocolMessageType(
    'QueryPoolResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPOOLRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolResponse)
    },
)
_sym_db.RegisterMessage(QueryPoolResponse)

QueryPoolsRequest = _reflection.GeneratedProtocolMessageType(
    'QueryPoolsRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPOOLSREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolsRequest)
    },
)
_sym_db.RegisterMessage(QueryPoolsRequest)

QueryPoolsResponse = _reflection.GeneratedProtocolMessageType(
    'QueryPoolsResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPOOLSRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolsResponse)
    },
)
_sym_db.RegisterMessage(QueryPoolsResponse)

QueryPoolParamsRequest = _reflection.GeneratedProtocolMessageType(
    'QueryPoolParamsRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPOOLPARAMSREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolParamsRequest)
    },
)
_sym_db.RegisterMessage(QueryPoolParamsRequest)

QueryPoolParamsResponse = _reflection.GeneratedProtocolMessageType(
    'QueryPoolParamsResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYPOOLPARAMSRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolParamsResponse)
    },
)
_sym_db.RegisterMessage(QueryPoolParamsResponse)

QueryNumPoolsRequest = _reflection.GeneratedProtocolMessageType(
    'QueryNumPoolsRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYNUMPOOLSREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryNumPoolsRequest)
    },
)
_sym_db.RegisterMessage(QueryNumPoolsRequest)

QueryNumPoolsResponse = _reflection.GeneratedProtocolMessageType(
    'QueryNumPoolsResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYNUMPOOLSRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryNumPoolsResponse)
    },
)
_sym_db.RegisterMessage(QueryNumPoolsResponse)

QueryTotalLiquidityRequest = _reflection.GeneratedProtocolMessageType(
    'QueryTotalLiquidityRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYTOTALLIQUIDITYREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalLiquidityRequest)
    },
)
_sym_db.RegisterMessage(QueryTotalLiquidityRequest)

QueryTotalLiquidityResponse = _reflection.GeneratedProtocolMessageType(
    'QueryTotalLiquidityResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYTOTALLIQUIDITYRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalLiquidityResponse)
    },
)
_sym_db.RegisterMessage(QueryTotalLiquidityResponse)

QueryTotalPoolLiquidityRequest = _reflection.GeneratedProtocolMessageType(
    'QueryTotalPoolLiquidityRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYTOTALPOOLLIQUIDITYREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalPoolLiquidityRequest)
    },
)
_sym_db.RegisterMessage(QueryTotalPoolLiquidityRequest)

QueryTotalPoolLiquidityResponse = _reflection.GeneratedProtocolMessageType(
    'QueryTotalPoolLiquidityResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYTOTALPOOLLIQUIDITYRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalPoolLiquidityResponse)
    },
)
_sym_db.RegisterMessage(QueryTotalPoolLiquidityResponse)

QueryTotalSharesRequest = _reflection.GeneratedProtocolMessageType(
    'QueryTotalSharesRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYTOTALSHARESREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalSharesRequest)
    },
)
_sym_db.RegisterMessage(QueryTotalSharesRequest)

QueryTotalSharesResponse = _reflection.GeneratedProtocolMessageType(
    'QueryTotalSharesResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYTOTALSHARESRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalSharesResponse)
    },
)
_sym_db.RegisterMessage(QueryTotalSharesResponse)

QuerySpotPriceRequest = _reflection.GeneratedProtocolMessageType(
    'QuerySpotPriceRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYSPOTPRICEREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySpotPriceRequest)
    },
)
_sym_db.RegisterMessage(QuerySpotPriceRequest)

QuerySpotPriceResponse = _reflection.GeneratedProtocolMessageType(
    'QuerySpotPriceResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYSPOTPRICERESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySpotPriceResponse)
    },
)
_sym_db.RegisterMessage(QuerySpotPriceResponse)

QuerySwapExactAmountInRequest = _reflection.GeneratedProtocolMessageType(
    'QuerySwapExactAmountInRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYSWAPEXACTAMOUNTINREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountInRequest)
    },
)
_sym_db.RegisterMessage(QuerySwapExactAmountInRequest)

QuerySwapExactAmountInResponse = _reflection.GeneratedProtocolMessageType(
    'QuerySwapExactAmountInResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYSWAPEXACTAMOUNTINRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountInResponse)
    },
)
_sym_db.RegisterMessage(QuerySwapExactAmountInResponse)

QuerySwapExactAmountOutRequest = _reflection.GeneratedProtocolMessageType(
    'QuerySwapExactAmountOutRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYSWAPEXACTAMOUNTOUTREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountOutRequest)
    },
)
_sym_db.RegisterMessage(QuerySwapExactAmountOutRequest)

QuerySwapExactAmountOutResponse = _reflection.GeneratedProtocolMessageType(
    'QuerySwapExactAmountOutResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYSWAPEXACTAMOUNTOUTRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountOutResponse)
    },
)
_sym_db.RegisterMessage(QuerySwapExactAmountOutResponse)

QueryJoinExactAmountInRequest = _reflection.GeneratedProtocolMessageType(
    'QueryJoinExactAmountInRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYJOINEXACTAMOUNTINREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountInRequest)
    },
)
_sym_db.RegisterMessage(QueryJoinExactAmountInRequest)

QueryJoinExactAmountInResponse = _reflection.GeneratedProtocolMessageType(
    'QueryJoinExactAmountInResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYJOINEXACTAMOUNTINRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountInResponse)
    },
)
_sym_db.RegisterMessage(QueryJoinExactAmountInResponse)

QueryJoinExactAmountOutRequest = _reflection.GeneratedProtocolMessageType(
    'QueryJoinExactAmountOutRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYJOINEXACTAMOUNTOUTREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountOutRequest)
    },
)
_sym_db.RegisterMessage(QueryJoinExactAmountOutRequest)

QueryJoinExactAmountOutResponse = _reflection.GeneratedProtocolMessageType(
    'QueryJoinExactAmountOutResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYJOINEXACTAMOUNTOUTRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountOutResponse)
    },
)
_sym_db.RegisterMessage(QueryJoinExactAmountOutResponse)

QueryExitExactAmountInRequest = _reflection.GeneratedProtocolMessageType(
    'QueryExitExactAmountInRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYEXITEXACTAMOUNTINREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountInRequest)
    },
)
_sym_db.RegisterMessage(QueryExitExactAmountInRequest)

QueryExitExactAmountInResponse = _reflection.GeneratedProtocolMessageType(
    'QueryExitExactAmountInResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYEXITEXACTAMOUNTINRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountInResponse)
    },
)
_sym_db.RegisterMessage(QueryExitExactAmountInResponse)

QueryExitExactAmountOutRequest = _reflection.GeneratedProtocolMessageType(
    'QueryExitExactAmountOutRequest',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYEXITEXACTAMOUNTOUTREQUEST,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountOutRequest)
    },
)
_sym_db.RegisterMessage(QueryExitExactAmountOutRequest)

QueryExitExactAmountOutResponse = _reflection.GeneratedProtocolMessageType(
    'QueryExitExactAmountOutResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _QUERYEXITEXACTAMOUNTOUTRESPONSE,
        '__module__': 'dex.v1.query_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountOutResponse)
    },
)
_sym_db.RegisterMessage(QueryExitExactAmountOutResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/NibiruChain/nibiru/x/dex/types'
    _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
    _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
    _QUERYTOTALLIQUIDITYRESPONSE.fields_by_name['liquidity']._options = None
    _QUERYTOTALLIQUIDITYRESPONSE.fields_by_name[
        'liquidity'
    ]._serialized_options = (
        b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"liquidity\"\310\336\037\000'
    )
    _QUERYTOTALPOOLLIQUIDITYRESPONSE.fields_by_name['liquidity']._options = None
    _QUERYTOTALPOOLLIQUIDITYRESPONSE.fields_by_name[
        'liquidity'
    ]._serialized_options = (
        b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"liquidity\"\310\336\037\000'
    )
    _QUERYTOTALSHARESRESPONSE.fields_by_name['total_shares']._options = None
    _QUERYTOTALSHARESRESPONSE.fields_by_name[
        'total_shares'
    ]._serialized_options = b'\362\336\037\023yaml:\"total_shares\"\310\336\037\000'
    _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['token_in']._options = None
    _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name[
        'token_in'
    ]._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
    _QUERYSWAPEXACTAMOUNTINRESPONSE.fields_by_name['token_out']._options = None
    _QUERYSWAPEXACTAMOUNTINRESPONSE.fields_by_name[
        'token_out'
    ]._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
    _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['token_out']._options = None
    _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name[
        'token_out'
    ]._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
    _QUERYSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['token_in']._options = None
    _QUERYSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name[
        'token_in'
    ]._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
    _QUERYJOINEXACTAMOUNTINREQUEST.fields_by_name['tokens_in']._options = None
    _QUERYJOINEXACTAMOUNTINREQUEST.fields_by_name[
        'tokens_in'
    ]._serialized_options = (
        b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"tokens_in\"\310\336\037\000'
    )
    _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name['pool_shares_out']._options = None
    _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name[
        'pool_shares_out'
    ]._serialized_options = (
        b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"pool_shares_out\"\310\336\037\000'
    )
    _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name['rem_coins']._options = None
    _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name[
        'rem_coins'
    ]._serialized_options = (
        b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"rem_coins\"\310\336\037\000'
    )
    _QUERYEXITEXACTAMOUNTINREQUEST.fields_by_name['pool_shares_in']._options = None
    _QUERYEXITEXACTAMOUNTINREQUEST.fields_by_name[
        'pool_shares_in'
    ]._serialized_options = (
        b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\025yaml:\"pool_shares_in\"\310\336\037\000'
    )
    _QUERYEXITEXACTAMOUNTINRESPONSE.fields_by_name['tokens_out']._options = None
    _QUERYEXITEXACTAMOUNTINRESPONSE.fields_by_name[
        'tokens_out'
    ]._serialized_options = (
        b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\021yaml:\"tokens_out\"\310\336\037\000'
    )
    _QUERY.methods_by_name['Params']._options = None
    _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\024\022\022/nibiru/dex/params'
    _QUERY.methods_by_name['PoolNumber']._options = None
    _QUERY.methods_by_name[
        'PoolNumber'
    ]._serialized_options = b'\202\323\344\223\002\031\022\027/nibiru/dex/pool_number'
    _QUERY.methods_by_name['Pool']._options = None
    _QUERY.methods_by_name['Pool']._serialized_options = b'\202\323\344\223\002\022\022\020/nibiru/dex/pool'
    _QUERY.methods_by_name['Pools']._options = None
    _QUERY.methods_by_name['Pools']._serialized_options = b'\202\323\344\223\002\023\022\021/nibiru/dex/pools'
    _QUERY.methods_by_name['PoolParams']._options = None
    _QUERY.methods_by_name[
        'PoolParams'
    ]._serialized_options = b'\202\323\344\223\002$\022\"/nibiru/dex/pools/{pool_id}/params'
    _QUERY.methods_by_name['NumPools']._options = None
    _QUERY.methods_by_name['NumPools']._serialized_options = b'\202\323\344\223\002\027\022\025/nibiru/dex/num_pools'
    _QUERY.methods_by_name['TotalLiquidity']._options = None
    _QUERY.methods_by_name[
        'TotalLiquidity'
    ]._serialized_options = b'\202\323\344\223\002\035\022\033/nibiru/dex/total_liquidity'
    _QUERY.methods_by_name['TotalPoolLiquidity']._options = None
    _QUERY.methods_by_name[
        'TotalPoolLiquidity'
    ]._serialized_options = b'\202\323\344\223\0022\0220/nibiru/dex/pools/{pool_id}/total_pool_liquidity'
    _QUERY.methods_by_name['TotalShares']._options = None
    _QUERY.methods_by_name[
        'TotalShares'
    ]._serialized_options = b'\202\323\344\223\002*\022(/nibiru/dex/pools/{pool_id}/total_shares'
    _QUERY.methods_by_name['SpotPrice']._options = None
    _QUERY.methods_by_name[
        'SpotPrice'
    ]._serialized_options = b'\202\323\344\223\002$\022\"/nibiru/dex/pools/{pool_id}/prices'
    _QUERY.methods_by_name['EstimateSwapExactAmountIn']._options = None
    _QUERY.methods_by_name[
        'EstimateSwapExactAmountIn'
    ]._serialized_options = b'\202\323\344\223\0025\0223/nibiru/dex/{pool_id}/estimate/swap_exact_amount_in'
    _QUERY.methods_by_name['EstimateSwapExactAmountOut']._options = None
    _QUERY.methods_by_name[
        'EstimateSwapExactAmountOut'
    ]._serialized_options = b'\202\323\344\223\0026\0224/nibiru/dex/{pool_id}/estimate/swap_exact_amount_out'
    _QUERY.methods_by_name['EstimateJoinExactAmountIn']._options = None
    _QUERY.methods_by_name[
        'EstimateJoinExactAmountIn'
    ]._serialized_options = b'\202\323\344\223\0025\0223/nibiru/dex/{pool_id}/estimate/join_exact_amount_in'
    _QUERY.methods_by_name['EstimateJoinExactAmountOut']._options = None
    _QUERY.methods_by_name[
        'EstimateJoinExactAmountOut'
    ]._serialized_options = b'\202\323\344\223\0026\0224/nibiru/dex/{pool_id}/estimate/join_exact_amount_out'
    _QUERY.methods_by_name['EstimateExitExactAmountIn']._options = None
    _QUERY.methods_by_name[
        'EstimateExitExactAmountIn'
    ]._serialized_options = b'\202\323\344\223\0025\0223/nibiru/dex/{pool_id}/estimate/exit_exact_amount_in'
    _QUERY.methods_by_name['EstimateExitExactAmountOut']._options = None
    _QUERY.methods_by_name[
        'EstimateExitExactAmountOut'
    ]._serialized_options = b'\202\323\344\223\0026\0224/nibiru/dex/{pool_id}/estimate/exit_exact_amount_out'
    _QUERYPARAMSREQUEST._serialized_start = 205
    _QUERYPARAMSREQUEST._serialized_end = 225
    _QUERYPARAMSRESPONSE._serialized_start = 227
    _QUERYPARAMSRESPONSE._serialized_end = 293
    _QUERYPOOLNUMBERREQUEST._serialized_start = 295
    _QUERYPOOLNUMBERREQUEST._serialized_end = 319
    _QUERYPOOLNUMBERRESPONSE._serialized_start = 321
    _QUERYPOOLNUMBERRESPONSE._serialized_end = 363
    _QUERYPOOLREQUEST._serialized_start = 365
    _QUERYPOOLREQUEST._serialized_end = 400
    _QUERYPOOLRESPONSE._serialized_start = 402
    _QUERYPOOLRESPONSE._serialized_end = 456
    _QUERYPOOLSREQUEST._serialized_start = 458
    _QUERYPOOLSREQUEST._serialized_end = 537
    _QUERYPOOLSRESPONSE._serialized_start = 539
    _QUERYPOOLSRESPONSE._serialized_end = 656
    _QUERYPOOLPARAMSREQUEST._serialized_start = 658
    _QUERYPOOLPARAMSREQUEST._serialized_end = 699
    _QUERYPOOLPARAMSRESPONSE._serialized_start = 701
    _QUERYPOOLPARAMSRESPONSE._serialized_end = 774
    _QUERYNUMPOOLSREQUEST._serialized_start = 776
    _QUERYNUMPOOLSREQUEST._serialized_end = 798
    _QUERYNUMPOOLSRESPONSE._serialized_start = 800
    _QUERYNUMPOOLSRESPONSE._serialized_end = 842
    _QUERYTOTALLIQUIDITYREQUEST._serialized_start = 844
    _QUERYTOTALLIQUIDITYREQUEST._serialized_end = 872
    _QUERYTOTALLIQUIDITYRESPONSE._serialized_start = 875
    _QUERYTOTALLIQUIDITYRESPONSE._serialized_end = 1020
    _QUERYTOTALPOOLLIQUIDITYREQUEST._serialized_start = 1022
    _QUERYTOTALPOOLLIQUIDITYREQUEST._serialized_end = 1071
    _QUERYTOTALPOOLLIQUIDITYRESPONSE._serialized_start = 1074
    _QUERYTOTALPOOLLIQUIDITYRESPONSE._serialized_end = 1223
    _QUERYTOTALSHARESREQUEST._serialized_start = 1225
    _QUERYTOTALSHARESREQUEST._serialized_end = 1267
    _QUERYTOTALSHARESRESPONSE._serialized_start = 1269
    _QUERYTOTALSHARESRESPONSE._serialized_end = 1373
    _QUERYSPOTPRICEREQUEST._serialized_start = 1375
    _QUERYSPOTPRICEREQUEST._serialized_end = 1464
    _QUERYSPOTPRICERESPONSE._serialized_start = 1466
    _QUERYSPOTPRICERESPONSE._serialized_end = 1510
    _QUERYSWAPEXACTAMOUNTINREQUEST._serialized_start = 1513
    _QUERYSWAPEXACTAMOUNTINREQUEST._serialized_end = 1656
    _QUERYSWAPEXACTAMOUNTINRESPONSE._serialized_start = 1658
    _QUERYSWAPEXACTAMOUNTINRESPONSE._serialized_end = 1762
    _QUERYSWAPEXACTAMOUNTOUTREQUEST._serialized_start = 1765
    _QUERYSWAPEXACTAMOUNTOUTREQUEST._serialized_end = 1910
    _QUERYSWAPEXACTAMOUNTOUTRESPONSE._serialized_start = 1912
    _QUERYSWAPEXACTAMOUNTOUTRESPONSE._serialized_end = 2015
    _QUERYJOINEXACTAMOUNTINREQUEST._serialized_start = 2018
    _QUERYJOINEXACTAMOUNTINREQUEST._serialized_end = 2182
    _QUERYJOINEXACTAMOUNTINRESPONSE._serialized_start = 2185
    _QUERYJOINEXACTAMOUNTINRESPONSE._serialized_end = 2432
    _QUERYJOINEXACTAMOUNTOUTREQUEST._serialized_start = 2434
    _QUERYJOINEXACTAMOUNTOUTREQUEST._serialized_end = 2483
    _QUERYJOINEXACTAMOUNTOUTRESPONSE._serialized_start = 2485
    _QUERYJOINEXACTAMOUNTOUTRESPONSE._serialized_end = 2518
    _QUERYEXITEXACTAMOUNTINREQUEST._serialized_start = 2521
    _QUERYEXITEXACTAMOUNTINREQUEST._serialized_end = 2666
    _QUERYEXITEXACTAMOUNTINRESPONSE._serialized_start = 2669
    _QUERYEXITEXACTAMOUNTINRESPONSE._serialized_end = 2819
    _QUERYEXITEXACTAMOUNTOUTREQUEST._serialized_start = 2821
    _QUERYEXITEXACTAMOUNTOUTREQUEST._serialized_end = 2870
    _QUERYEXITEXACTAMOUNTOUTRESPONSE._serialized_start = 2872
    _QUERYEXITEXACTAMOUNTOUTRESPONSE._serialized_end = 2905
    _QUERY._serialized_start = 2908
    _QUERY._serialized_end = 5329
# @@protoc_insertion_point(module_scope)



import logging
from copy import deepcopy

from google.protobuf import message
from grpc import RpcError

from nibiru.client import Client
from nibiru.common import TxConfig, TxType
from nibiru.composer import Composer
from nibiru.constant import GAS_PRICE
from nibiru.exceptions import SimulationError, TxError
from nibiru.network import Network
from nibiru.transaction import Transaction
from nibiru.wallet import PrivateKey


class Tx:
    def __init__(self, priv_key: PrivateKey, network: Network, client: Client, config: TxConfig):
        self.priv_key = priv_key
        self.network = network
        self.client = client
        self.address = None
        self.config = config
        self.msgs = []

    def add_messages(self, *msgs: message.Message):
        self.msgs.extend(msgs)
        return self

    def execute(self, **kwargs):
        try:
            res = self.execute_msg(*self.msgs, **kwargs)
        except SimulationError as err:
            raise err
        else:
            self.msgs = []

        return res

    def execute_msg(self, *msg: message.Message, **kwargs):
        try:
            # TODO: It shouldn't be necessary to resync the block height for every tx, use bgTask instead
            self.client.sync_timeout_height()
            address = self.get_address_info()
            tx = (
                Transaction()
                .with_messages(*msg)
                .with_sequence(address.get_sequence())
                .with_account_num(address.get_number())
                .with_chain_id(self.network.chain_id)
                .with_signer(self.priv_key)
            )
            sim_res = self.simulate(tx)
            gas_estimate = sim_res.gas_info.gas_used
            return self.execute_tx(tx, gas_estimate, **kwargs)
        except (RpcError, SimulationError) as err:
            logging.error("Failed tx execution: %s", err)
            address.decrease_sequence()
            raise TxError("Failed to execute transaction") from err

    def execute_tx(self, tx: Transaction, gas_estimate: float, **kwargs):
        conf = self.get_config(**kwargs)
        gas_wanted = gas_estimate * 1.25
        if conf.gas_wanted > 0:
            gas_wanted = conf.gas_wanted
        elif conf.gas_multiplier > 0:
            gas_wanted = gas_estimate * conf.gas_multiplier
        gas_price = GAS_PRICE if conf.gas_price <= 0 else conf.gas_price

        fee = [
            Composer.coin(
                amount=int(gas_price * gas_wanted),
                denom=self.network.fee_denom,
            )
        ]
        logging.info("Executing transaction with fee: %s and gas_wanted: %d", fee, gas_wanted)
        tx = tx.with_gas(gas_wanted).with_fee(fee).with_memo("").with_timeout_height(self.client.timeout_height)
        tx_raw_bytes = tx.get_signed_tx_data()

        return self._send_tx(tx_raw_bytes, conf.tx_type)

    def _send_tx(self, tx_raw_bytes, tx_type: TxType):
        if tx_type == TxType.SYNC:
            return self.client.send_tx_sync_mode(tx_raw_bytes)
        elif tx_type == TxType.ASYNC:
            return self.client.send_tx_async_mode(tx_raw_bytes)

        return self.client.send_tx_block_mode(tx_raw_bytes)

    def simulate(self, tx: Transaction):
        sim_tx_raw_bytes = tx.get_signed_tx_data()

        (sim_res, success) = self.client.simulate_tx(sim_tx_raw_bytes)
        if not success:
            raise SimulationError("failed to simulate tx : {}".format(sim_res))

        return sim_res

    def get_address_info(self):
        if self.address is None:
            pub_key = self.priv_key.to_public_key()
            self.address = pub_key.to_address().init_num_seq(self.network.lcd_endpoint)

        return self.address

    def get_config(self, **kwargs):
        """
        Properties in kwargs overwrite config
        """
        c = deepcopy(self.config)
        props = dir(c)
        for (k, v) in kwargs.items():
            if k in props:
                setattr(c, k, v)
            else:
                logging.warning("%s is not a supported config property, ignoring", k)

        return c



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pricefeed import query_pb2 as pricefeed_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service for pricefeed module
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.QueryParams = channel.unary_unary(
                '/nibiru.pricefeed.v1.Query/QueryParams',
                request_serializer=pricefeed_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=pricefeed_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.QueryPrice = channel.unary_unary(
                '/nibiru.pricefeed.v1.Query/QueryPrice',
                request_serializer=pricefeed_dot_query__pb2.QueryPriceRequest.SerializeToString,
                response_deserializer=pricefeed_dot_query__pb2.QueryPriceResponse.FromString,
                )
        self.QueryPrices = channel.unary_unary(
                '/nibiru.pricefeed.v1.Query/QueryPrices',
                request_serializer=pricefeed_dot_query__pb2.QueryPricesRequest.SerializeToString,
                response_deserializer=pricefeed_dot_query__pb2.QueryPricesResponse.FromString,
                )
        self.QueryRawPrices = channel.unary_unary(
                '/nibiru.pricefeed.v1.Query/QueryRawPrices',
                request_serializer=pricefeed_dot_query__pb2.QueryRawPricesRequest.SerializeToString,
                response_deserializer=pricefeed_dot_query__pb2.QueryRawPricesResponse.FromString,
                )
        self.QueryOracles = channel.unary_unary(
                '/nibiru.pricefeed.v1.Query/QueryOracles',
                request_serializer=pricefeed_dot_query__pb2.QueryOraclesRequest.SerializeToString,
                response_deserializer=pricefeed_dot_query__pb2.QueryOraclesResponse.FromString,
                )
        self.QueryMarkets = channel.unary_unary(
                '/nibiru.pricefeed.v1.Query/QueryMarkets',
                request_serializer=pricefeed_dot_query__pb2.QueryMarketsRequest.SerializeToString,
                response_deserializer=pricefeed_dot_query__pb2.QueryMarketsResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service for pricefeed module
    """

    def QueryParams(self, request, context):
        """QueryParams queries all parameters of the pricefeed module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryPrice(self, request, context):
        """QueryPrice queries price details for a pair
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryPrices(self, request, context):
        """QueryPrices queries all prices
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryRawPrices(self, request, context):
        """QueryRawPrices queries all raw prices for an asset pair
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryOracles(self, request, context):
        """QueryOracles queries all oracles for an asset pair
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QueryMarkets(self, request, context):
        """QueryMarkets queries all markets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'QueryParams': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryParams,
                    request_deserializer=pricefeed_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=pricefeed_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'QueryPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryPrice,
                    request_deserializer=pricefeed_dot_query__pb2.QueryPriceRequest.FromString,
                    response_serializer=pricefeed_dot_query__pb2.QueryPriceResponse.SerializeToString,
            ),
            'QueryPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryPrices,
                    request_deserializer=pricefeed_dot_query__pb2.QueryPricesRequest.FromString,
                    response_serializer=pricefeed_dot_query__pb2.QueryPricesResponse.SerializeToString,
            ),
            'QueryRawPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryRawPrices,
                    request_deserializer=pricefeed_dot_query__pb2.QueryRawPricesRequest.FromString,
                    response_serializer=pricefeed_dot_query__pb2.QueryRawPricesResponse.SerializeToString,
            ),
            'QueryOracles': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryOracles,
                    request_deserializer=pricefeed_dot_query__pb2.QueryOraclesRequest.FromString,
                    response_serializer=pricefeed_dot_query__pb2.QueryOraclesResponse.SerializeToString,
            ),
            'QueryMarkets': grpc.unary_unary_rpc_method_handler(
                    servicer.QueryMarkets,
                    request_deserializer=pricefeed_dot_query__pb2.QueryMarketsRequest.FromString,
                    response_serializer=pricefeed_dot_query__pb2.QueryMarketsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.pricefeed.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service for pricefeed module
    """

    @staticmethod
    def QueryParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.pricefeed.v1.Query/QueryParams',
            pricefeed_dot_query__pb2.QueryParamsRequest.SerializeToString,
            pricefeed_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.pricefeed.v1.Query/QueryPrice',
            pricefeed_dot_query__pb2.QueryPriceRequest.SerializeToString,
            pricefeed_dot_query__pb2.QueryPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.pricefeed.v1.Query/QueryPrices',
            pricefeed_dot_query__pb2.QueryPricesRequest.SerializeToString,
            pricefeed_dot_query__pb2.QueryPricesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryRawPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.pricefeed.v1.Query/QueryRawPrices',
            pricefeed_dot_query__pb2.QueryRawPricesRequest.SerializeToString,
            pricefeed_dot_query__pb2.QueryRawPricesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryOracles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.pricefeed.v1.Query/QueryOracles',
            pricefeed_dot_query__pb2.QueryOraclesRequest.SerializeToString,
            pricefeed_dot_query__pb2.QueryOraclesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def QueryMarkets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.pricefeed.v1.Query/QueryMarkets',
            pricefeed_dot_query__pb2.QueryMarketsRequest.SerializeToString,
            pricefeed_dot_query__pb2.QueryMarketsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from lockup.v1 import tx_pb2 as lockup_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.LockTokens = channel.unary_unary(
                '/nibiru.lockup.v1.Msg/LockTokens',
                request_serializer=lockup_dot_v1_dot_tx__pb2.MsgLockTokens.SerializeToString,
                response_deserializer=lockup_dot_v1_dot_tx__pb2.MsgLockTokensResponse.FromString,
                )
        self.InitiateUnlock = channel.unary_unary(
                '/nibiru.lockup.v1.Msg/InitiateUnlock',
                request_serializer=lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlock.SerializeToString,
                response_deserializer=lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlockResponse.FromString,
                )
        self.Unlock = channel.unary_unary(
                '/nibiru.lockup.v1.Msg/Unlock',
                request_serializer=lockup_dot_v1_dot_tx__pb2.MsgUnlock.SerializeToString,
                response_deserializer=lockup_dot_v1_dot_tx__pb2.MsgUnlockResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def LockTokens(self, request, context):
        """LockTokens lock tokens
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitiateUnlock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Unlock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'LockTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.LockTokens,
                    request_deserializer=lockup_dot_v1_dot_tx__pb2.MsgLockTokens.FromString,
                    response_serializer=lockup_dot_v1_dot_tx__pb2.MsgLockTokensResponse.SerializeToString,
            ),
            'InitiateUnlock': grpc.unary_unary_rpc_method_handler(
                    servicer.InitiateUnlock,
                    request_deserializer=lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlock.FromString,
                    response_serializer=lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlockResponse.SerializeToString,
            ),
            'Unlock': grpc.unary_unary_rpc_method_handler(
                    servicer.Unlock,
                    request_deserializer=lockup_dot_v1_dot_tx__pb2.MsgUnlock.FromString,
                    response_serializer=lockup_dot_v1_dot_tx__pb2.MsgUnlockResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.lockup.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def LockTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.lockup.v1.Msg/LockTokens',
            lockup_dot_v1_dot_tx__pb2.MsgLockTokens.SerializeToString,
            lockup_dot_v1_dot_tx__pb2.MsgLockTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitiateUnlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.lockup.v1.Msg/InitiateUnlock',
            lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlock.SerializeToString,
            lockup_dot_v1_dot_tx__pb2.MsgInitiateUnlockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Unlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.lockup.v1.Msg/Unlock',
            lockup_dot_v1_dot_tx__pb2.MsgUnlock.SerializeToString,
            lockup_dot_v1_dot_tx__pb2.MsgUnlockResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
